@@ -3,24 +3,31 @@
 
 import requests
 
-from info import InfoAPI
-
 class BaseAPI(object):
-    '''
-    DNSPod base API object.
+    '''BaseAPI is used by every other API objects.
+
+    BaseAPI hold informations that will used by other API objects during every
+    API operation.
     '''
 
     LANG_EN = 'en'
     LANG_CN = 'cn'
-    DEFAULT_LANG = LANG_EN
     DEFAULT_API_URL = 'https://dnsapi.cn/'
 
-    def __init__(self, login_email, login_password, **kwargs):
+    def __init__(self, login_email, login_password, lang=LANG_EN, api_url=DEFAULT_API_URL):
+        '''Initialize object with DNSPod account and options
+
+        :param str login_email: Account Email address
+        :param str login_password: Account password
+        :param str lang: Error returning language. By default, ``LANG_EN`` is
+                         used, avaliable values: ``LANG_EN``, ``LANG_CN``
+        :param str api_url: API url, default: ``DEFAULT_API_URL``
+        '''
         self.login_email = login_email
         self.login_password = login_password
         self.format = 'json'
-        self.lang = kwargs.get('lang', self.DEFAULT_LANG)
-        self.api_url = kwargs.get('api_url', self.DEFAULT_API_URL)
+        self.lang = lang
+        self.api_url = api_url
 
     def do_post(self, interface, **params):
         common_param = {
